/*
 *      edit-operations.c
 *
 *      Copyright 2007 Florian Sievers <florian@dopehouse.dyndns.org>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>

#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>

#include "edit-operations.h"

#include "support.h"

void edit_cut_clipboard(GtkWidget *widget, const gchar *widget_name)
{
	GtkWidget *target_widget, *main_window;
	GtkClipboard *clipboard;
	GtkTextBuffer *buffer;

	main_window = lookup_widget(widget, "main_window");
	if(widget_name == NULL)
	{
		target_widget = gtk_window_get_focus(GTK_WINDOW(main_window));
	}
	else
	{
		target_widget = lookup_widget(widget, widget_name);
	}

	/* return if focused widget isn't a text view */
	g_return_if_fail(GTK_IS_TEXT_VIEW(target_widget));

	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(target_widget));
	/* get clipboard */
	clipboard = gtk_widget_get_clipboard(target_widget, GDK_SELECTION_CLIPBOARD);

	/* cut selected buffer */
	gtk_text_buffer_cut_clipboard(buffer, clipboard, TRUE);

	/* scroll text view to the cut-point */
	gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(target_widget), gtk_text_buffer_get_insert(buffer), 0.0, FALSE, 0.0, 0.0);

	return;
}

void edit_copy_clipboard(GtkWidget *widget, const gchar *widget_name)
{
	GtkWidget *target_widget, *main_window;
	GtkClipboard *clipboard;
	GtkTextBuffer *buffer;

	main_window = lookup_widget(widget, "main_window");
	if(widget_name == NULL)
	{
		target_widget = gtk_window_get_focus(GTK_WINDOW(main_window));
	}
	else
	{
		target_widget = lookup_widget(widget, widget_name);
	}

	/* return if focused widget isn't a text view */
	g_return_if_fail(GTK_IS_TEXT_VIEW(target_widget));

	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(target_widget));
	/* get clipboard */
	clipboard = gtk_widget_get_clipboard(target_widget, GDK_SELECTION_CLIPBOARD);

	/* copy selected buffer */
	gtk_text_buffer_copy_clipboard(buffer, clipboard);

	return;
}

void edit_paste_clipboard(GtkWidget *widget, const gchar *widget_name)
{
	GtkWidget *target_widget, *main_window;
	GtkClipboard *clipboard;
	GtkTextBuffer *buffer;

	main_window = lookup_widget(widget, "main_window");
	if(widget_name == NULL)
	{
		target_widget = gtk_window_get_focus(GTK_WINDOW(main_window));
	}
	else
	{
		target_widget = lookup_widget(widget, widget_name);
	}

	/* return if focused widget isn't a text view */
	g_return_if_fail(GTK_IS_TEXT_VIEW(target_widget));

	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(target_widget));
	/* get clipboard */
	clipboard = gtk_widget_get_clipboard(target_widget, GDK_SELECTION_CLIPBOARD);

	/* paste clipboard to buffer */
	gtk_text_buffer_paste_clipboard(buffer, clipboard, NULL, TRUE);

	/* scroll text view to the cut-point */
	gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(target_widget), gtk_text_buffer_get_insert(buffer), 0.0, FALSE, 0.0, 0.0);

	return;
}

void edit_delete_clipboard(GtkWidget *widget, const gchar *widget_name)
{
	GtkWidget *target_widget, *main_window;
	GtkTextBuffer *buffer;

	main_window = lookup_widget(widget, "main_window");
	if(widget_name == NULL)
	{
		target_widget = gtk_window_get_focus(GTK_WINDOW(main_window));
	}
	else
	{
		target_widget = lookup_widget(widget, widget_name);
	}

	/* return if focused widget isn't a text view */
	g_return_if_fail(GTK_IS_TEXT_VIEW(target_widget));

	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(target_widget));

	/* delete selected buffer */
	gtk_text_buffer_delete_selection(buffer, TRUE, TRUE);

	/* scroll text view to the cut-point */
	gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(target_widget), gtk_text_buffer_get_insert(buffer), 0.0, FALSE, 0.0, 0.0);

	return;
}
