/*
 *      main.c - GPG-Crypter
 *
 *      Copyright 2006 Florian Sievers <florian@dopehouse.dyndns.org>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; version 2 of the License.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <gtk/gtk.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <errno.h>

#include <gpgme.h>

#include "gpg-crypter.h"

#include "interface.h"
#include "support.h"

int main(int argc, char *argv[])
{
	GtkWidget *main_window;
	GtkWidget *aboutdialog;
	GtkWidget *key_id_combobox;

	/* Initialize app_data */
	app_data = malloc(sizeof(application_data));
	if(app_data == NULL)
	{
		printf(_("Memory allocation error\n"));
	}

#ifdef ENABLE_NLS
	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
	textdomain (GETTEXT_PACKAGE);
#endif

	gtk_set_locale ();
	gtk_init (&argc, &argv);

	/* gpg initialization helper function */
	if(gpg_init(app_data, GPGME_PROTOCOL_OpenPGP))
	{
		printf(_("Unable to initialize OpenPGP!\n"));
		exit(0);
	}

	add_pixmap_directory (PACKAGE_DATA_DIR "/" PACKAGE "/pixmaps");

	/* initialize keys and put them into the key_combo */
	/* Test if there were some gpg-keys. If not, than exit with error dialog. */
	if(!(app_data->num_keys > 0))
	{
		GtkWidget *error_dialog;
		error_dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, g_locale_to_utf8("No GPG-Keys found. Please create one with gpg --gen-key\n", -1, NULL, NULL, NULL));
		gtk_dialog_run(GTK_DIALOG(error_dialog));
		gtk_widget_destroy(GTK_WIDGET(error_dialog));
		gpg_release(app_data);
		exit(0);
	}

	/*
	* The following code was added by Glade to create one of each component
	* (except popup menus), just so that you see something after building
	* the project. Delete any components that you don't want shown initially.
	*/
	main_window = create_main_window();
	gtk_widget_show(main_window);

	key_id_combobox = lookup_widget(main_window, "key_combobox");
	g_ptr_array_foreach(app_data->key_string_array, insert_combobox_row, key_id_combobox);
	gtk_combo_box_set_active(GTK_COMBO_BOX(key_id_combobox), 0);

	app_data->buffer_plaintext = gtk_text_view_get_buffer(GTK_TEXT_VIEW(lookup_widget(main_window, "plaintext_textview")));
	app_data->buffer_cipher = gtk_text_view_get_buffer(GTK_TEXT_VIEW(lookup_widget(main_window, "cipher_textview")));

	gtk_main ();

	/* cleanup */
	gpg_release(app_data);
	free(app_data);

	return 0;
}

